/* SQL script  version II 9.3.0                                   */
/* It migrates SpagoBI repository from release 2.3 to release 2.4 */
/* Launch this script by SQL Ingres console                       */
/*----------------------------------------------------------------*/

\sql
set autocommit on
\p\g
\sql
set session with privileges=all
\p\g

/* Modifies to add Model Label */
ALTER TABLE SBI_KPI_MODEL ADD COLUMN KPI_MODEL_LBL VARCHAR(100) NOT NULL
\p\g
UPDATE SBI_KPI_MODEL SET KPI_MODEL_LBL = KPI_MODEL_CD
\p\g
ALTER TABLE SBI_KPI_MODEL DROP INDEX KPI_MODEL_CD
\p\g
ALTER TABLE SBI_KPI_MODEL ADD UNIQUE INDEX UNIQUE_LABEL(KPI_MODEL_LBL)
\p\g
ALTER TABLE SBI_KPI_MODEL ADD UNIQUE INDEX UNIQUE_PAR_ID_CD(KPI_PARENT_MODEL_ID, KPI_MODEL_CD)
\p\g

/* Modifies SBI_THRESHOLD_VALUE TABLE to add the selection to specify if the range is open or closed */
ALTER TABLE SBI_THRESHOLD_VALUE ADD COLUMN MIN_CLOSED TINYINT
\p\g
ALTER TABLE SBI_THRESHOLD_VALUE ADD COLUMN MAX_CLOSED TINYINT
\p\g
ALTER TABLE SBI_THRESHOLD_VALUE ADD COLUMN VALUE Float
\p\g

/* Modifies SBI_KPI_MODEL_INST to specify a KPI INSTANCE or a MODEL INSTANCE LABEL */
ALTER TABLE SBI_KPI_MODEL_INST ADD COLUMN MODELUUID VARCHAR(400)
\p\g

ALTER TABLE SBI_LOV MODIFY COLUMN LOV_PROVIDER TEXT DEFAULT NULL
\p\g

/**Internal profiling tables*/
CREATE TABLE SBI_USER (
	USER_ID VARCHAR(100) NOT NULL,
	PASSWORD VARCHAR(150),
	FULL_NAME VARCHAR(255),
	ID INTEGER NOT NULL,
 PRIMARY KEY (ID))
 \p\g

CREATE TABLE SBI_ATTRIBUTE (
	ATTRIBUTE_NAME VARCHAR(255) NOT NULL,
	DESCRIPTION VARCHAR(500) NOT NULL,
	ATTRIBUTE_ID INTEGER NOT NULL,
 PRIMARY KEY (ATTRIBUTE_ID))
 \p\g

CREATE TABLE SBI_USER_ATTRIBUTES (
	ID INTEGER NOT NULL,
	ATTRIBUTE_ID INTEGER NOT NULL,
	ATTRIBUTE_VALUE VARCHAR(500),
 PRIMARY KEY (ID,ATTRIBUTE_ID))
 \p\g


CREATE TABLE SBI_EXT_USER_ROLES (
	ID INTEGER NOT NULL,
	EXT_ROLE_ID INTEGER NOT NULL,
 PRIMARY KEY (ID,EXT_ROLE_ID))
 \p\g

ALTER TABLE SBI_USER_ATTRIBUTES ADD FOREIGN KEY (ID) REFERENCES SBI_USER (ID)
\p\g
ALTER TABLE SBI_EXT_USER_ROLES ADD FOREIGN KEY (ID) REFERENCES SBI_USER (ID)
\p\g
ALTER TABLE SBI_USER_ATTRIBUTES ADD FOREIGN KEY (ATTRIBUTE_ID) REFERENCES SBI_ATTRIBUTE (ATTRIBUTE_ID)
\p\g
ALTER TABLE SBI_EXT_USER_ROLES ADD FOREIGN KEY (EXT_ROLE_ID) REFERENCES SBI_EXT_ROLES (EXT_ROLE_ID)
\p\g

ALTER TABLE SBI_USER ADD COLUMN DT_PWD_BEGIN TIMESTAMP
\p\g
ALTER TABLE SBI_USER ADD COLUMN DT_PWD_END TIMESTAMP
\p\g
ALTER TABLE SBI_USER ADD COLUMN FLG_PWD_BLOCKED BOOLEAN
\p\g
ALTER TABLE SBI_USER ADD COLUMN DT_LAST_ACCESS TIMESTAMP
\p\g

--adds new funcionality for internal profiling management
INSERT INTO SBI_USER_FUNC (NAME, DESCRIPTION) VALUES ('ProfileManagement', 'ProfileManagement')
\p\g
INSERT INTO SBI_ROLE_TYPE_USER_FUNC (ROLE_TYPE_ID, USER_FUNCT_ID)
 SELECT a.VALUE_ID  , b.USER_FUNCT_ID FROM
 (
  SELECT VALUE_ID FROM SBI_DOMAINS WHERE DOMAIN_CD = 'ROLE_TYPE' AND VALUE_CD = 'ADMIN' 
 ) a( VALUE_ID ) ,
 (
  SELECT USER_FUNCT_ID FROM SBI_USER_FUNC WHERE NAME='ProfileManagement'
 ) b(USER_FUNCT_ID );
\p\g


/** configuration table*/
CREATE SEQUENCE SBI_CONFIG_SEQ
\p\g
CREATE TABLE SBI_CONFIG (
	ID 				INTEGER NOT NULL with default next value for SBI_CONFIG_SEQ,
	LABEL			VARCHAR(100) NOT NULL,
	NAME			VARCHAR(100) NULL,
	DESCRIPTION 	VARCHAR(500) NULL,
	IS_ACTIVE 		TINYINT Default 1,
	VALUE_CHECK 	VARCHAR(1000) NULL,
	VALUE_TYPE_ID 	INTEGER NULL,    
 PRIMARY KEY (ID))
 \p\g
 
 
CREATE UNIQUE INDEX XAK1SBI_CONFIG ON SBI_CONFIG
(
       LABEL                          ASC
)
\p\g

CREATE INDEX XIF3SBI_CONFIG ON SBI_CONFIG
(
       VALUE_TYPE_ID                  ASC
)
\p\g

ALTER TABLE SBI_CONFIG ADD CONSTRAINT FK_sbi_config_1 FOREIGN KEY ( VALUE_TYPE_ID ) REFERENCES SBI_DOMAINS ( VALUE_ID )
\p\g


/** change creation date datatype (date --> timestamp) */
CREATE TABLE SBI_VIEWPOINTS_TMP AS SELECT * FROM SBI_VIEWPOINTS
\p\g
DROP TABLE SBI_VIEWPOINTS
\p\g

Create table SBI_VIEWPOINTS (
	VP_ID Integer NOT NULL with default next value for SBI_VIEWPOINTS_SEQ,
	BIOBJ_ID Integer NOT NULL,
	VP_NAME Varchar(40) NOT NULL,
	VP_OWNER Varchar(40),
	VP_DESC Varchar(160),
	VP_SCOPE Varchar(20) NOT NULL,
	VP_VALUE_PARAMS Long nvarchar,
	VP_CREATION_DATE TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
Primary Key (VP_ID)
) 
\p\g
alter table SBI_VIEWPOINTS ADD CONSTRAINT FK_SBI_VIEWPOINTS_1 foreign key (BIOBJ_ID) references SBI_OBJECTS (BIOBJ_ID)
\p\g

insert into SBI_VIEWPOINTS (VP_ID,BIOBJ_ID, VP_NAME,VP_OWNER,VP_DESC,VP_SCOPE,VP_VALUE_PARAMS,VP_CREATION_DATE)  select VP_ID,BIOBJ_ID, VP_NAME,VP_OWNER,VP_DESC,VP_SCOPE,VP_VALUE_PARAMS,VP_CREATION_DATE from SBI_VIEWPOINTS_TMP
\p\g
DROP TABLE SBI_VIEWPOINTS_TMP
\p\g
   
CREATE SEQUENCE SBI_ACTIVITY_SEQ;\p\g

CREATE TABLE SBI_ACTIVITY_MONITORING (
  ID INTEGER  NOT NULL with default next value for  SBI_ACTIVITY_SEQ,
  ACTION_TIME   timestamp,
  USERNAME 	 	VARCHAR(40) NOT NULL,
  USERGROUP		VARCHAR(400),
  LOG_LEVEL 	VARCHAR(10) ,
  ACTION_CODE 	VARCHAR(45) NOT NULL,
  INFO 			VARCHAR(400),
  PRIMARY KEY (ID)
) ;\p\g
